==> hs-criterion-0.4.1.0.tbz: lib/criterion-0.4.1.0/register.sh <==
#!/bin/sh

echo 'name: criterion
version: 0.4.1.0
license: BSD3
copyright: 2009 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability:
homepage:
package-url:
description: This library provides a powerful but simple way to measure the
             performance of Haskell code.  It provides both a framework for
             executing and analysing benchmarks and a set of driver functions
             that makes it easy to build and run benchmarks, and to analyse their
             results.
             .
             The fastest way to get started is to read the documentation and
             examples in the Criterion.Main module.
category: Development, Performance, Testing
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules: Criterion Criterion.Analysis Criterion.Config
                 Criterion.Environment Criterion.IO Criterion.Main
                 Criterion.Measurement Criterion.Monad Criterion.MultiMap
                 Criterion.Plot Criterion.Types
hidden-modules:
import-dirs: /usr/local/lib/criterion-0.4.1.0/ghc-6.10.4
library-dirs: /usr/local/lib/criterion-0.4.1.0/ghc-6.10.4
hs-libraries: HScriterion-0.4.1.0
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.1.0.0 bytestring-0.9.1.4 containers-0.2.0.1
         deepseq-1.1.0.0 filepath-1.1.0.2 mtl-1.1.0.2 parallel-1.1.0.1
         parsec-2.1.0.1 statistics-0.4.1 time-1.1.4 uvector-0.1.1.0
         uvector-algorithms-0.2
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/criterion-0.4.1.0/html/criterion.haddock
haddock-html: /usr/local/share/doc/criterion-0.4.1.0/html' | /usr/local/bin/ghc-pkg update -

==> hs-criterion-0.5.0.0.tbz: lib/criterion-0.5.0.0/register.sh <==
#!/bin/sh

echo 'name: criterion
version: 0.5.0.0
license: BSD3
copyright: 2009-2010 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability:
homepage:
package-url:
description: This library provides a powerful but simple way to measure the
             performance of Haskell code.  It provides both a framework for
             executing and analysing benchmarks and a set of driver functions
             that makes it easy to build and run benchmarks, and to analyse their
             results.
             .
             The fastest way to get started is to read the documentation and
             examples in the Criterion.Main module.
category: Development, Performance, Testing
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules: Criterion Criterion.Analysis Criterion.Config
                 Criterion.Environment Criterion.IO Criterion.Main
                 Criterion.Measurement Criterion.Monad Criterion.MultiMap
                 Criterion.Plot Criterion.Types
hidden-modules:
import-dirs: /usr/local/lib/criterion-0.5.0.0/ghc-6.10.4
library-dirs: /usr/local/lib/criterion-0.5.0.0/ghc-6.10.4
              /usr/local/lib
hs-libraries: HScriterion-0.5.0.0
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.1.0.0 bytestring-0.9.1.4 containers-0.2.0.1
         deepseq-1.1.0.0 filepath-1.1.0.2 mtl-1.1.0.2 mwc-random-0.5.0.0
         parallel-1.1.0.1 parsec-2.1.0.1 statistics-0.5.1.0 time-1.1.4
         vector-0.6.0.1 vector-algorithms-0.3.2
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/criterion-0.5.0.0/html/criterion.haddock
haddock-html: /usr/local/share/doc/criterion-0.5.0.0/html' | /usr/local/bin/ghc-pkg update -
